@@ -198,8 +198,8 @@ onOK <- function(){
 	tkfocus(CommanderWindow())
 	}
 OKCancelHelp(helpSubject="zsum")
-tkgrid(tklabel(top, text="x-axis"), xEntry, sticky="e")
-tkgrid(tklabel(top, text="y-axis"), yEntry, sticky="e")
+tkgrid(tklabel(top, text=gettext("x-axis", domain="R-RcmdrPlugin.orloca")), xEntry, sticky="e")
+tkgrid(tklabel(top, text=gettext("y-axis", domain="R-RcmdrPlugin.orloca")), yEntry, sticky="e")
 tkgrid(buttonsFrame, sticky="w", columnspan=2)
 tkgrid.configure(xEntry, sticky="w")
 tkgrid.configure(yEntry, sticky="w")
@@ -216,6 +216,8 @@ nVar <- tclVar("100")
 nEntry <- tkentry(top, width="6", textvariable=nVar)
 epsVar <- tclVar("0.001")
 epsEntry <- tkentry(top, width="6", textvariable=epsVar)
+gettext("Gradient", domain="R-RcmdrPlugin.orloca")
+gettext("Search method", domain="R-RcmdrPlugin.orloca")
 radioButtons(name="algorithm", buttons=c("w", "g", "s", "u"), values=c("w", "g", "s", "u"), initialValue="w", labels=gettext(c("Weiszfeld", "Gradient", "Search method", "ucminf"), domain="R-RcmdrPlugin.orloca"), title=gettext("Select algorithm", domain="R-RcmdrPlugin.orloca"))
 
 #tkgrid(labelRcmdr(statisticFrame), sticky="w")
@@ -254,13 +256,13 @@ onOK <- function(){
 	tkfocus(CommanderWindow())
 	}
 OKCancelHelp(helpSubject="zsummin")
-tkgrid(tklabel(top, text="Iter. Max."), nEntry, sticky="w")
+tkgrid(tklabel(top, text=gettext("Maximum number of iterations", domain="R-RcmdrPlugin.orloca")), nEntry, sticky="w")
 tkgrid.configure(nEntry, sticky="e")
-tkgrid(tklabel(top, text="x-axis"), xEntry, sticky="w")
+tkgrid(tklabel(top, text=gettext("x-axis", domain="R-RcmdrPlugin.orloca")), xEntry, sticky="w")
 tkgrid.configure(xEntry, sticky="e")
-tkgrid(tklabel(top, text="y-axis"), yEntry, sticky="w")
+tkgrid(tklabel(top, text=gettext("y-axis", domain="R-RcmdrPlugin.orloca")), yEntry, sticky="w")
 tkgrid.configure(yEntry, sticky="e")
-tkgrid(tklabel(top, text="Grad. norm."), epsEntry, sticky="w")
+tkgrid(tklabel(top, text=gettext("Maximum gradient norm", domain="R-RcmdrPlugin.orloca")), epsEntry, sticky="w")
 tkgrid.configure(epsEntry, sticky="e")
 tkgrid.configure(algorithmFrame, sticky="w")
 tkgrid(algorithmFrame, sticky="w", columnspan=2)
